@@ -15,7 +15,7 @@ def main():
     if len(sys.argv) >= 4:
 
         if sys.argv[2] == "-f" or sys.argv[2] == "--file":
-            print("Feature Not Yet Implemented")
+            fromFile(sys.argv[3])
 
         elif sys.argv[2] == "-d" or sys.argv[2] == "--domain":
             print("Feature Not Yet Implemented")
@@ -112,6 +112,16 @@ def prepareOCSPRequest(certificate):
     elif(sys.argv[1] == "-g" or sys.argv[1] == "--GET" or sys.argv[1] == "--get"):
         sendOCSPRequestGET(base64Request.decode(), ocspUrl)
 
+
+def fromFile(fileName):
+
+    base64CertificateFile = open(fileName, 'rb')
+    base64Certificate = base64CertificateFile.read()
+    certificate = x509.load_pem_x509_certificate(base64Certificate, default_backend())
+
+    prepareOCSPRequest(certificate)
+
+
 def crtsh(crtshId):
 
     base64Certificate = requests.get('https://crt.sh/?d=' + crtshId)
@@ -137,7 +147,7 @@ def help():
           "\n"
           "Optional -if issuer.pem Parameter: Use a local file to indicate the issuing CA instead of finding it in the certificate\n"
           "\n"
-          "ocsp_check version 0.0.11\n"
+          "ocsp_check version 0.0.14\n"
           "Author: Martijn Katerbarg")
 
 
@@ -160,10 +170,11 @@ def getCAIssuer(certificate):
 
     except ExtensionNotFound:
         print("ERROR: Certificate AIA Extension Missing. Possible Root Certificate.")
-
+        exit(-1)
 
 def getOCSPServerURL(certificate):
-    global ocsp_url
+
+    ocspUrl = None
 
     try:
         authorityInfoAccess = certificate.extensions.get_extension_for_oid(
@@ -171,17 +182,18 @@ def getOCSPServerURL(certificate):
 
         for authorityInfoAccessMethod in iter((authorityInfoAccess)):
             if authorityInfoAccessMethod.__getattribute__("access_method")._name == "OCSP":
-                ocsp_url = authorityInfoAccessMethod.__getattribute__("access_location").value
+                ocspUrl = authorityInfoAccessMethod.__getattribute__("access_location").value
 
-        if len(ocsp_url) > 6:
-            return ocsp_url
+        if ocspUrl is None:
+            print("ERROR: No OCSP Server URL found in certificate. Quitting.")
+            exit(-1)
 
         else:
-            raise ValueError("No OCSP Server URL found in certificate")
+            return ocspUrl
 
     except ExtensionNotFound:
         print("ERROR: Certificate AIA Extension Missing. Possible Root Certificate.")
-
+        exit(-1)
 
 def incorrectSyntax():
     print("Incorrect Syntax. Please see 'ocsp_check -h' for usage and help")
